# Install

## [AUR](https://aur.archlinux.org/packages/zathura-language-server)

```sh
paru -S zathura-language-server
```

## [NUR](https://nur.nix-community.org/repos/Freed-Wu)

```sh
nix-env -iA nixos.nur.repos.Freed-Wu.zathura-language-server
```

## [PYPI](https://pypi.org/project/zathura-language-server)

```sh
pip install zathura-language-server
```

See [requirements](requirements) to know `extra_requires`.
